@@ -784,7 +784,7 @@ def signup(request):
             raw_password = form.cleaned_data.get('password1')
             user = authenticate(username=username, password=raw_password)
             login(request, user)
-            return redirect('home')
+            return redirect('hubs')
     else:
         form = UserCreationForm()
     return render(request, 'registration/signup.html', {'form': form})
\ No newline at end of file
